<?php 
/**
 * Main plugin file. This plugin adds useful admin links and resources for the WooCommerce Shop Plugin to the WordPress Admin Bar.
 *
 * @package WooCommerceAdminBarAddition
 * @author David Decker
 *
 * @credits Inspired and based on the plugin "WooThemes Admin Bar Addition" by Remkus de Vries @defries.
 * @link http://remkusdevries.com/
 * @link http://twitter.com/#!/defries
 *
 * Plugin Name: WooCommerce Admin Bar Addition
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/woocommerce-admin-bar-addition/
 * Description: This plugin adds useful admin links and resources for the WooCommerce Shop Plugin to the WodPress Admin Bar.
 * Version: 1.0
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2
 * Text Domain: wcaba
 * Domain Path: /languages/
 */

/**
 * Setting constants
 *
 * @since 1.0
 */
define( 'WCABA_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


/**
 * Load the text domain for translation of the plugin
 * 
 * @since 1.0
 */
load_plugin_textdomain( 'wcaba', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );


add_filter( 'plugin_row_meta', 'ddw_woocommerce_aba_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0
 */
function ddw_woocommerce_aba_plugin_links( $wcaba_links, $wcaba_file ) {

	if ( !current_user_can( 'install_plugins' ))
		return $wcaba_links;

	if ( $wcaba_file == WCABA_PLUGIN_BASEDIR . '/woocommerce-admin-bar-addition.php' ) {
		$wcaba_links[] = '<a href="http://wordpress.org/extend/plugins/woocommerce-admin-bar-addition/faq/" target="_new" title="' . __( 'FAQ', 'wcaba' ) . '">' . __( 'FAQ', 'wcaba' ) . '</a>';
		$wcaba_links[] = '<a href="http://wordpress.org/tags/woocommerce-admin-bar-addition?forum_id=10" target="_new" title="' . __( 'Support', 'wcaba' ) . '">' . __( 'Support', 'wcaba' ) . '</a>';
		$wcaba_links[] = '<a href="' . __( 'http://genesisthemes.de/en/donate/', 'wcaba' ) . '" target="_new" title="' . __( 'Donate', 'wcaba' ) . '">' . __( 'Donate', 'wcaba' ) . '</a>';
	}

	return $wcaba_links;
}


add_action( 'admin_bar_menu', 'ddw_woocommerce_aba_admin_bar_menu', 98 );
/**
 * Add new menu items to the WP Admin Bar.
 * 
 * @since 1.0
 *
 * @global mixed $wp_admin_bar 
 */
function ddw_woocommerce_aba_admin_bar_menu() {
	global $wp_admin_bar;

	// Required WooCommerce/ WordPress cabability to display new admin bar entry
	if ( !current_user_can( 'manage_woocommerce' ) || !is_admin_bar_showing() )
		return;

	// Set unique prefix
	$prefix = 'ddw-woocommerce-';
	
	// Create parent menu item references
	$woocommercebar = $prefix . 'admin-bar';
	$support = $prefix . 'wcsupport';
	$woocodex = $prefix . 'codex';
	$woocommercesites = $prefix . 'woocommercesites';
	$settings = $prefix . 'settings';
	$products = $prefix . 'products';
	$coupons = $prefix . 'coupons';
	$orders = $prefix . 'orders';
	$reports = $prefix . 'reports';
	$extensions = $prefix . 'extensions';
	
	// Display these items also when WooCommerce plugin is not installed
	$menu_items = array(
		'wcsupport' => array(
			'parent' => $woocommercebar,
			'title'  => __( 'WooCommerce Support', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/support-forum/?viewforum=131'
		),
		'wccodex' => array(
			'parent' => $woocommercebar,
			'title'  => __( 'WooCommerce Codex', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/woocommerce-codex/'
		),
		'wcuserguide' => array(
			'parent' => $woocommercebar,
			'title'  => __( 'WooCommerce User Guide', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/woocommerce-codex/woocommerce-user-guide/'
		),
		'wcforum' => array(
			'parent' => $support,
			'title'  => __( 'WooCommerce Forum', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/support-forum/?viewforum=131'
		),
		'wcsupportwporg' => array(
			'parent' => $support,
			'title'  => __( 'Free Support Forum (WP.org)', 'wcaba' ),
			'href'   => 'http://wordpress.org/tags/woocommerce?forum_id=10'
		),
		'woocommercesites' => array(
			'parent' => $woocommercebar,
			'title'  => __( 'WooCommerce HQ', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/woocommerce/'
		),
		'wcideas' => array(
			'parent' => $woocommercesites,
			'title'  => __( 'Ideas &amp; Feature Requests', 'wcaba' ),
			'href'   => 'http://woo.uservoice.com/forums/133476-woocommerce'
		),
		'wcbugs' => array(
			'parent' => $woocommercesites,
			'title'  => __( 'Issues &amp; Bug Reports', 'wcaba' ),
			'href'   => 'https://github.com/woothemes/woocommerce/issues'
		),
		'wcdev' => array(
			'parent' => $woocommercesites,
			'title'  => __( 'GitHub Repository Developer Center', 'wcaba' ),
			'href'   => 'https://github.com/woothemes/woocommerce/'
		),
		'wcextensions' => array(
			'parent' => $woocommercesites,
			'title'  => __( 'Official WooCommerce Extensions', 'wcaba' ),
			'href'   => 'http://www.woothemes.com/extensions/woocommerce-extensions/'
		),
		'wcplugins' => array(
			'parent' => $woocommercesites,
			'title'  => __( 'More free plugins/extensions at WP.org', 'wcaba' ),
			'href'   => 'http://wordpress.org/extend/plugins/search.php?q=woocommerce'
		),
	);

	// Display links to downloadable language packs only for these locales: de_DE, de_AT, de_CH, de_LU
	if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
		$menu_items['languages-de'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'German language files', 'wcaba' ),
			'href'   => 'http://deckerweb.de/material/sprachdateien/woocommerce-und-extensions/'
		);
	}

	// Display links to language plugin only for this locale: nl, nl_NL
	if ( get_locale() == 'nl' || get_locale() == 'nl_NL' ) {
		$menu_items['languages-nl'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Dutch language plugin', 'wcaba' ),
			'href'   => 'http://wordpress.org/extend/plugins/woocommerce-nl/'
		);
	}

	// Show these items only if WooCommerce plugin is actually installed
	if ( function_exists ( 'woocommerce_init' ) ) {
		$menu_items['settings'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Shop Settings', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['s-general-settings'] = array(
			'parent' => $settings,
			'title'  => __( 'General Settings', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=general' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['s-shop-pages'] = array(
			'parent' => $settings,
			'title'  => __( 'Shop Pages', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=pages' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['s-shop-catalog'] = array(
			'parent' => $settings,
			'title'  => __( 'Shop Catalog', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=catalog' ),
			'meta'   => array( 'target' => '' )			
		);
		$menu_items['s-inventory'] = array(
			'parent' => $settings,
			'title'  => __( 'Inventory', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=inventory' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['s-shipping-costs'] = array(
			'parent' => $settings,
			'title'  => __( 'Shipping Costs', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=shipping' ),
			'meta'   => array( 'target' => '')
		);
		$menu_items['s-shipping-methods'] = array(
			'parent' => $settings,
			'title'  => __( 'Shipping Methods', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=shipping_methods' ),
			'meta'   => array( 'target' => '')
		);
		$menu_items['s-taxes'] = array(
			'parent' => $settings,
			'title'  => __( 'Taxes', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=tax' ),
			'meta'   => array( 'target' => '')
		);
		$menu_items['s-payment-gateways'] = array(
			'parent' => $settings,
			'title'  => __( 'Paymet Gateways', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=payment_gateways' ),
			'meta'   => array( 'target' => '')
		);
		$menu_items['s-emails'] = array(
			'parent' => $settings,
			'title'  => __( 'Emails', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce&tab=email' ),
			'meta'   => array( 'target' => '')
		);
		$menu_items['s-widgets'] = array(
			'parent' => $settings,
			'title'  => __( 'WooCommerce Widgets', 'wcaba' ),
			'href'   => admin_url( 'widgets.php' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['products'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Products', 'wcaba' ),
			'href'   => admin_url( 'edit.php?post_type=product' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['p-add-product'] = array(
			'parent' => $products,
			'title'  => __( 'Add new product', 'wcaba' ),
			'href'   => admin_url( 'post-new.php?post_type=product' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['p-product-categories'] = array(
			'parent' => $products,
			'title'  => __( 'Product Categories', 'wcaba' ),
			'href'   => admin_url( 'edit-tags.php?taxonomy=product_cat&post_type=product' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['p-product-tags'] = array(
			'parent' => $products,
			'title'  => __( 'Product Tags', 'wcaba' ),
			'href'   => admin_url( 'edit-tags.php?taxonomy=product_tag&post_type=product' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['p-product-variants'] = array(
			'parent' => $products,
			'title'  => __( 'Product Variants (Attributes)', 'wcaba' ),
			'href'   => admin_url( 'edit.php?post_type=product&page=woocommerce_attributes' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['orders'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Orders', 'wcaba' ),
			'href'   => admin_url( 'edit.php?post_type=shop_order' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['o-add-order'] = array(
			'parent' => $orders,
			'title'  => __( 'Add new order', 'wcaba' ),
			'href'   => admin_url( 'post-new.php?post_type=shop_order' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['coupons'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Coupons', 'wcaba' ),
			'href'   => admin_url( 'edit.php?post_type=shop_coupon' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['c-add-coupon'] = array(
			'parent' => $coupons,
			'title'  => __( 'Add new coupon', 'wcaba' ),
			'href'   => admin_url( 'post-new.php?post_type=shop_coupon' ),
			'meta'   => array( 'target' => '' )
		);
		$menu_items['reports'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Reports', 'wcaba' ),
			'href'   => admin_url( 'admin.php?page=woocommerce_reports' ),
			'meta'   => array( 'target' => '' )
		);
		// Display last main item for active extensions/plugins
		$menu_items['extensions'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'Active Extenions', 'wcaba' ),
				'href'   => admin_url( 'plugins.php' ),
				'meta'   => array( 'target' => '' )
		);
	}

	// Display link to active WooThemes theme settings page (WooThemes, free & premium)
	if ( function_exists ( 'woo_version_init' ) ) {
		$menu_items['woothemes-settings'] = array(
			'parent' => $woocommercebar,
			'title'  => __( 'WooThemes Settings', 'wcaba' ),
				'href'   => admin_url( 'admin.php?page=woothemes' ),
				'meta'   => array( 'target' => '' )
		);
	}


	/**
	 * Display links to active plugins/extensions settings' pages
	 *
	 * @since 1.0
	 */

	// WooCommerce Exporter (Visser Labs, free)
	if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'woocommerce-exporter/exporter.php' ) ) || function_exists( 'woo_ce_admin_init' ) ) {
		$menu_items['ext-exporter'] = array(
			'parent' => $extensions,
			'title'  => __( 'WooCommerce Exporter', 'wcaba' ),
			'href'   => admin_url( 'tools.php?page=woo_ce' ),
			'meta'   => array( 'target' => '' )
		);
	}

	// WooCommerce Store Toolkit (Visser Labs, free)
	if ( ( function_exists( 'is_plugin_active' ) && is_plugin_active( 'woocommerce-store-toolkit/store-toolkit.php' ) ) || function_exists( 'woo_st_init' ) ) {
		$menu_items['ext-store-toolkit'] = array(
			'parent' => $extensions,
			'title'  => __( 'WooCommerce Store Toolkit', 'wcaba' ),
			'href'   => admin_url( 'tools.php?page=woo_st' ),
			'meta'   => array( 'target' => '' )
		);
	}

	// Allow menu items to be filtered, but pass in parent menu item IDs
	$menu_items = (array) apply_filters( 'ddw_woocommerce_aba_menu_items', $menu_items, $prefix, $woocommercebar, $support, $woocodex, $woocommercesites, $settings, $products, $coupons, $orders, $reports, $extensions );

	// Add the top-level item
	$wp_admin_bar->add_menu( array(
		'id'    => $woocommercebar,
		'title' => __( 'WooCommerce', 'wcaba' ),
		'href'  => admin_url( 'admin.php?page=woocommerce' ),
		'meta'  => array( 'class' => 'icon-woocommerce' )
	) );

	// Loop through the menu items
	foreach ( $menu_items as $id => $menu_item ) {
		
		// Add in the item ID
		$menu_item['id'] = $prefix . $id;

		// Add meta target to each item where it's not already set, so links open in new window/tab
		if ( ! isset( $menu_item['meta']['target'] ) )		
			$menu_item['meta']['target'] = '_blank';

		// Add class to links that open up in a new window/tab
		if ( '_blank' === $menu_item['meta']['target'] ) {
			if ( ! isset( $menu_item['meta']['class'] ) )
				$menu_item['meta']['class'] = '';
			$menu_item['meta']['class'] .= $prefix . 'wcaba-new-tab';
		}

		// Add item
		$wp_admin_bar->add_menu( $menu_item );
	}		
}


add_action( 'wp_head', 'ddw_woocommerce_aba_admin_style' );
add_action( 'admin_head', 'ddw_woocommerce_aba_admin_style' );
/**
 * Add the styles for new WP Admin Bar entry
 * 
 * @since 1.0
 */
function ddw_woocommerce_aba_admin_style() {
	if ( ! is_admin_bar_showing() )
		return;

	?>
	<style type="text/css">
		#wpadminbar .icon-woocommerce > a {
			background: url(<?php echo plugins_url( 'woocommerce-admin-bar-addition/images/wcaba-icon.png' , dirname(__FILE__) ); ?>) no-repeat 0.85em 50% transparent;
			padding-left: 29px;
		}
		#wp-admin-bar-ddw-woocommerce-settings,
		#wp-admin-bar-ddw-woocommerce-extensions {
    			border-top: 1px solid;
		}
	</style>
	<?php
}
